California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 12 - 2000 AB 18 (CHAPTER 461, 1999). VILLARAIGOSA. BOND: PARKS, WATER, COASTAL PROTECTION ACT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
970866 | NATURE CONSERVANCY ACTION FUND OF CALIFORNIA, THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991829 | CALIFORNIANS FOR SAFE NEIGHBORHOOD PARKS & CLEAN WATER - YES ON PROPOSITIONS 12 & 13 SPONSORED BY CLEAN AIR, CLEAN WATER AND CONSERVATION GROUPS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991921 | YES ON 12 AND 13, A PROJECT OF THE PLANNING AND CONSERVATION LEAGUE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992200 | CALIFORNIANS FOR SAFE PARKS, A COMMITTEE FOR PROPOSITION 12 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992051 | CALIFORNIANS FOR SAFE PARKS-YES ON PROPOSITION 12 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992422 | SIERRA CLUB CALIFORNIA, YES ON PROPOSITION 12 COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1221840 | NEVADA COUNTY SUPPORTS PROP 12 COMMITTEE | SUPPORT